"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GuessOutputPath = exports.GuessOutputPathFromTargetString = exports.GuessOutputPathFromContext = void 0;
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const path_1 = require("path");
const project_1 = require("./project");
const project_target_1 = require("./project-target");
function GuessOutputPathFromContext(context, projectName = context.projectName, configurationName = context.configurationName, targetName = 'build') {
    if (!projectName) {
        throw new Error('The projectName is undefined. Ensure the projectName is passed into the executor context.');
    }
    const buildTarget = (0, project_target_1.GetProjectTarget)(context, projectName, targetName);
    if (!buildTarget) {
        throw new Error(`Could not find target 'build' for project '${projectName}'`);
    }
    const projectRoot = (0, project_1.GetProjectRoot)(context, projectName);
    return GuessOutputPath(projectRoot, buildTarget, configurationName);
}
exports.GuessOutputPathFromContext = GuessOutputPathFromContext;
function GuessOutputPathFromTargetString(context, targetString) {
    let configurationName = context.configurationName;
    let targetName = 'build';
    let projectName = context.projectName;
    if (targetString) {
        const [name, target, configuration] = targetString.split(':');
        if (!name) {
            throw new Error(`Could not extract the project name from the build target '${targetString}'`);
        }
        if (!target) {
            throw new Error(`Could not extract the target name from the build target '${targetString}'`);
        }
        projectName = name;
        targetName = target;
        configurationName = configuration;
    }
    return GuessOutputPathFromContext(context, projectName, configurationName, targetName);
}
exports.GuessOutputPathFromTargetString = GuessOutputPathFromTargetString;
function GuessOutputPath(projectRoot, buildTarget, configurationName) {
    let outputPath = (0, workspace_utilities_1.GetTargetOptions)(buildTarget, configurationName)['outputPath'];
    if (!outputPath) {
        if (buildTarget.outputs && buildTarget.outputs.length) {
            const [output] = buildTarget.outputs;
            if (output.match(/\.[a-zA-Z]+$/)) {
                outputPath = (0, path_1.dirname)(output);
            }
            else {
                outputPath = output;
            }
        }
        else {
            outputPath = (0, path_1.join)('dist', projectRoot);
        }
    }
    if (typeof outputPath !== 'string') {
        throw new Error(`The outputPath is not a string. Found: ${outputPath}`);
    }
    return outputPath
        .replace(/\{projectRoot}/, projectRoot)
        .replace(/\{workspaceRoot}\//, '');
}
exports.GuessOutputPath = GuessOutputPath;
//# sourceMappingURL=guess-output-path.js.map